@@ -7,7 +7,7 @@ use URI::Fetch 0.06;
 
 sub new {
     my $class = shift;
-    my $self  = $class->SUPER::new();
+    my $self  = $class->SUPER::new(@_);
 
     my $conf = Plagger->context->conf->{user_agent};
     if ($conf->{cookies}) {
@@ -18,6 +18,8 @@ sub new {
     $self->timeout( $conf->{timeout} || 15 );
     $self->env_proxy();
 
+    Plagger->context->run_hook('useragent.init', { ua => $self });
+
     $self;
 }
 
@@ -38,6 +40,13 @@ sub fetch {
     $res;
 }
 
+sub request {
+    my $self = shift;
+    my($req) = @_;
+    Plagger->context->run_hook('useragent.request', { ua => $self, url => $req->uri });
+    $self->SUPER::request(@_);
+}
+
 sub mirror {
     my($self, $request, $file) = @_;
 
